==> carpet-addons-not-found-1.20.6-2.2.0-sources.jar: carpetaddonsnotfound/lists/BlockList.java <==
package carpetaddonsnotfound.lists;

import java.util.*;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_2246;
import net.minecraft.class_2248;

import static java.util.Map.entry;

public class BlockList {
  public static List<class_2248> blueIce = Collections.singletonList(
          class_2246.field_10384);

  public static List<class_2248> cobbledDeepslate = Arrays.asList(
          class_2246.field_29031,
          class_2246.field_28889,
          class_2246.field_28890,
          class_2246.field_28891,
          class_2246.field_28892,
          class_2246.field_28893,
          class_2246.field_28894,
          class_2246.field_28895,
          class_2246.field_28896,
          class_2246.field_28897,
          class_2246.field_28898,
          class_2246.field_28899,
          class_2246.field_28900,
          class_2246.field_28901,
          class_2246.field_28902,
          class_2246.field_28903,
          class_2246.field_28904,
          class_2246.field_29222,
          class_2246.field_29223);

  public static List<class_2248> cobblestone = Arrays.asList(
          class_2246.field_10445,
          class_2246.field_10351,
          class_2246.field_10596,
          class_2246.field_10625,
          class_2246.field_9989,
          class_2246.field_10405,
          class_2246.field_10207,
          class_2246.field_9990);

  public static List<class_2248> deepslate = Collections.singletonList(
          class_2246.field_28888);

  public static List<class_2248> endStone = Arrays.asList(
          class_2246.field_10471,
          class_2246.field_10462,
          class_2246.field_10064,
          class_2246.field_10012,
          class_2246.field_10001);

  public static List<class_2248> netherBricks = Arrays.asList(
          class_2246.field_10266,
          class_2246.field_10364,
          class_2246.field_10390,
          class_2246.field_10159,
          class_2246.field_10127,
          class_2246.field_23867,
          class_2246.field_23866,
          class_2246.field_9986,
          class_2246.field_10478,
          class_2246.field_10497,
          class_2246.field_10311);

  public static List<class_2248> wood = Arrays.asList(
          // Fence Gates
          class_2246.field_10188,
          class_2246.field_10291,
          class_2246.field_10513,
          class_2246.field_10041,
          class_2246.field_10457,
          class_2246.field_10196,
          class_2246.field_22096,
          class_2246.field_22097,
          //#if MC>11802
          class_2246.field_37563,
          class_2246.field_42745,
          class_2246.field_40289,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_FENCE_GATE,
          //#endif

          // Fences
          class_2246.field_10620,
          class_2246.field_10020,
          class_2246.field_10299,
          class_2246.field_10319,
          class_2246.field_10144,
          class_2246.field_10132,
          class_2246.field_22132,
          class_2246.field_22133,
          //#if MC>11802
          class_2246.field_37565,
          class_2246.field_42747,
          class_2246.field_40290,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_FENCE,
          //#endif

          // Logs
          class_2246.field_10431,
          class_2246.field_10037,
          class_2246.field_10511,
          class_2246.field_10306,
          class_2246.field_10533,
          class_2246.field_10010,
          class_2246.field_22118,
          class_2246.field_22111,
          //#if MC>11802
          class_2246.field_37545,
          class_2246.field_42729,
          class_2246.field_41072,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_LOG,
          //#endif

          // Stripped Logs
          class_2246.field_10519,
          class_2246.field_10436,
          class_2246.field_10366,
          class_2246.field_10254,
          class_2246.field_10622,
          class_2246.field_10244,
          class_2246.field_22119,
          class_2246.field_22112,
          //#if MC>11802
          class_2246.field_37548,
          class_2246.field_42732,
          class_2246.field_41073,
          //#endif
          //#if MC>12103
          //$$ Blocks.STRIPPED_PALE_OAK_LOG,
          //#endif

          // Planks
          class_2246.field_10161,
          class_2246.field_9975,
          class_2246.field_10148,
          class_2246.field_10334,
          class_2246.field_10218,
          class_2246.field_10075,
          class_2246.field_22126,
          class_2246.field_22127,
          //#if MC>11802
          class_2246.field_37577,
          class_2246.field_42751,
          class_2246.field_40294,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_PLANKS,
          //#endif

          // "Wood"s
          class_2246.field_10126,
          class_2246.field_10155,
          class_2246.field_10307,
          class_2246.field_10303,
          class_2246.field_9999,
          class_2246.field_10178,
          class_2246.field_22505,
          class_2246.field_22503,
          //#if MC>11802
          class_2246.field_37549,
          class_2246.field_42733,
          class_2246.field_40295,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_WOOD,
          //#endif

          // Stripped "Wood"s
          class_2246.field_10250,
          class_2246.field_10558,
          class_2246.field_10204,
          class_2246.field_10084,
          class_2246.field_10103,
          class_2246.field_10374,
          class_2246.field_22506,
          class_2246.field_22504,
          //#if MC>11802
          class_2246.field_37550,
          class_2246.field_42730,
          //#endif
          //#if MC>12103
          //$$ Blocks.STRIPPED_PALE_OAK_WOOD,
          //#endif

          // Slabs
          class_2246.field_10119,
          class_2246.field_10071,
          class_2246.field_10257,
          class_2246.field_10617,
          class_2246.field_10031,
          class_2246.field_10500,
          class_2246.field_22128,
          class_2246.field_22129,
          //#if MC>11802
          class_2246.field_37564,
          class_2246.field_42746,
          class_2246.field_40292,
          class_2246.field_40293,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_SLAB,
          //#endif

          // Stairs
          class_2246.field_10563,
          class_2246.field_10569,
          class_2246.field_10408,
          class_2246.field_10122,
          class_2246.field_10256,
          class_2246.field_10616,
          class_2246.field_22098,
          class_2246.field_22099
          //#if MC>11802
          , class_2246.field_37561,
          class_2246.field_42744,
          class_2246.field_40287,
          class_2246.field_40288
          //#endif
          //#if MC>12103
          //$$ , Blocks.PALE_OAK_STAIRS
          //#endif
  );

  public static final Map<class_2248, class_1792> unobtainableBlocks = Map.ofEntries(
          entry(class_2246.field_9987, class_1802.field_8542),
          entry(class_2246.field_27160, class_1802.field_27065),
          entry(class_2246.field_10260, class_1802.field_8849)
          //#if MC>11802
          , entry(class_2246.field_38420, class_1802.field_38418)
          //#if MC>12006
          //$$ , entry(Blocks.TRIAL_SPAWNER, Items.TRIAL_SPAWNER),
          //$$ entry(Blocks.VAULT, Items.VAULT)
          //#endif
          //#endif
  );
}

==> carpet-addons-not-found-1.21.1-2.0.0-sources.jar: carpetaddonsnotfound/lists/BlockList.java <==
package carpetaddonsnotfound.lists;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import net.minecraft.class_2246;
import net.minecraft.class_2248;

public class BlockList {
  public static List<class_2248> blueIce = Collections.singletonList(
          class_2246.field_10384);

  public static List<class_2248> cobbledDeepslate = Arrays.asList(
          class_2246.field_29031,
          class_2246.field_28889,
          class_2246.field_28890,
          class_2246.field_28891,
          class_2246.field_28892,
          class_2246.field_28893,
          class_2246.field_28894,
          class_2246.field_28895,
          class_2246.field_28896,
          class_2246.field_28897,
          class_2246.field_28898,
          class_2246.field_28899,
          class_2246.field_28900,
          class_2246.field_28901,
          class_2246.field_28902,
          class_2246.field_28903,
          class_2246.field_28904,
          class_2246.field_29222,
          class_2246.field_29223);

  public static List<class_2248> cobblestone = Arrays.asList(
          class_2246.field_10445,
          class_2246.field_10351,
          class_2246.field_10596,
          class_2246.field_10625,
          class_2246.field_9989,
          class_2246.field_10405,
          class_2246.field_10207,
          class_2246.field_9990);

  public static List<class_2248> deepslate = Collections.singletonList(
          class_2246.field_28888);

  public static List<class_2248> endStone = Arrays.asList(
          class_2246.field_10471,
          class_2246.field_10462,
          class_2246.field_10064,
          class_2246.field_10012,
          class_2246.field_10001);

  public static List<class_2248> netherBricks = Arrays.asList(
          class_2246.field_10266,
          class_2246.field_10364,
          class_2246.field_10390,
          class_2246.field_10159,
          class_2246.field_10127,
          class_2246.field_23867,
          class_2246.field_23866,
          class_2246.field_9986,
          class_2246.field_10478,
          class_2246.field_10497,
          class_2246.field_10311);

  public static List<class_2248> wood = Arrays.asList(
          // Fence Gates
          class_2246.field_10188,
          class_2246.field_10291,
          class_2246.field_10513,
          class_2246.field_10041,
          class_2246.field_10457,
          class_2246.field_10196,
          class_2246.field_22096,
          class_2246.field_22097,
          //#if MC>11802
          class_2246.field_37563,
          class_2246.field_42745,
          class_2246.field_40289,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_FENCE_GATE,
          //#endif

          // Fences
          class_2246.field_10620,
          class_2246.field_10020,
          class_2246.field_10299,
          class_2246.field_10319,
          class_2246.field_10144,
          class_2246.field_10132,
          class_2246.field_22132,
          class_2246.field_22133,
          //#if MC>11802
          class_2246.field_37565,
          class_2246.field_42747,
          class_2246.field_40290,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_FENCE,
          //#endif

          // Logs
          class_2246.field_10431,
          class_2246.field_10037,
          class_2246.field_10511,
          class_2246.field_10306,
          class_2246.field_10533,
          class_2246.field_10010,
          class_2246.field_22118,
          class_2246.field_22111,
          //#if MC>11802
          class_2246.field_37545,
          class_2246.field_42729,
          class_2246.field_41072,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_LOG,
          //#endif

          // Stripped Logs
          class_2246.field_10519,
          class_2246.field_10436,
          class_2246.field_10366,
          class_2246.field_10254,
          class_2246.field_10622,
          class_2246.field_10244,
          class_2246.field_22119,
          class_2246.field_22112,
          //#if MC>11802
          class_2246.field_37548,
          class_2246.field_42732,
          class_2246.field_41073,
          //#endif
          //#if MC>12103
          //$$ Blocks.STRIPPED_PALE_OAK_LOG,
          //#endif

          // Planks
          class_2246.field_10161,
          class_2246.field_9975,
          class_2246.field_10148,
          class_2246.field_10334,
          class_2246.field_10218,
          class_2246.field_10075,
          class_2246.field_22126,
          class_2246.field_22127,
          //#if MC>11802
          class_2246.field_37577,
          class_2246.field_42751,
          class_2246.field_40294,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_PLANKS,
          //#endif

          // "Wood"s
          class_2246.field_10126,
          class_2246.field_10155,
          class_2246.field_10307,
          class_2246.field_10303,
          class_2246.field_9999,
          class_2246.field_10178,
          class_2246.field_22505,
          class_2246.field_22503,
          //#if MC>11802
          class_2246.field_37549,
          class_2246.field_42733,
          class_2246.field_40295,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_WOOD,
          //#endif

          // Stripped "Wood"s
          class_2246.field_10250,
          class_2246.field_10558,
          class_2246.field_10204,
          class_2246.field_10084,
          class_2246.field_10103,
          class_2246.field_10374,
          class_2246.field_22506,
          class_2246.field_22504,
          //#if MC>11802
          class_2246.field_37550,
          class_2246.field_42730,
          //#endif
          //#if MC>12103
          //$$ Blocks.STRIPPED_PALE_OAK_WOOD,
          //#endif

          // Slabs
          class_2246.field_10119,
          class_2246.field_10071,
          class_2246.field_10257,
          class_2246.field_10617,
          class_2246.field_10031,
          class_2246.field_10500,
          class_2246.field_22128,
          class_2246.field_22129,
          //#if MC>11802
          class_2246.field_37564,
          class_2246.field_42746,
          class_2246.field_40292,
          class_2246.field_40293,
          //#endif
          //#if MC>12103
          //$$ Blocks.PALE_OAK_SLAB,
          //#endif

          // Stairs
          class_2246.field_10563,
          class_2246.field_10569,
          class_2246.field_10408,
          class_2246.field_10122,
          class_2246.field_10256,
          class_2246.field_10616,
          class_2246.field_22098,
          class_2246.field_22099
          //#if MC>11802
          , class_2246.field_37561,
          class_2246.field_42744,
          class_2246.field_40287,
          class_2246.field_40288
          //#endif
          //#if MC>12103
          //$$ , Blocks.PALE_OAK_STAIRS
          //#endif
  );
}
